"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const core_1 = require("@oclif/core");
const command_1 = tslib_1.__importDefault(require("../command"));
class History extends command_1.default {
    async run() {
        const { flags } = await this.parse(History);
        try {
            const APIClient = await this.getAPIClient();
            const history = await APIClient.getHistory();
            core_1.ux.table(history, {
                id: {
                    header: 'ID',
                },
                title: {},
                userPath: {
                    header: 'User Path',
                },
                teamPath: {
                    header: 'Team Path',
                },
            }, Object.assign({ printLine: this.log.bind(this) }, flags));
        }
        catch (error) {
            this.log('Fetch history failed');
            this.error(error);
        }
    }
}
History.description = 'List user browse history';
History.examples = [
    `$ hackmd-cli history
ID                     Title                            User Path               Team Path
────────────────────── ──────────────────────────────── ────────────────────── ────────
raUuSTetT5uQbqQfLnz9lA CLI test note                    gvfz2UB5THiKABQJQnLs6Q null
BnC6gN0_TfStV2KKmPPXeg Welcome to your team's workspace null                   CLI-test `,
];
History.flags = Object.assign({ help: core_1.Flags.help({ char: 'h' }) }, core_1.ux.table.flags());
exports.default = History;
