"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const core_1 = require("@oclif/core");
const fs = tslib_1.__importStar(require("node:fs"));
const command_1 = tslib_1.__importDefault(require("../../command"));
const flags_1 = require("../../flags");
const open_editor_1 = tslib_1.__importDefault(require("../../open-editor"));
const utils_1 = require("../../utils");
class CreateCommand extends command_1.default {
    async run() {
        const { flags } = await this.parse(CreateCommand);
        const pipeString = (0, utils_1.safeStdinRead)();
        const options = {
            title: flags.title,
            content: pipeString || flags.content,
            readPermission: flags.readPermission,
            writePermission: flags.writePermission,
            commentPermission: flags.commentPermission,
        };
        if (flags.editor) {
            try {
                const mdFile = (0, utils_1.temporaryMD)();
                await (0, open_editor_1.default)(mdFile);
                options.content = fs.readFileSync(mdFile).toString();
            }
            catch (error) {
                this.error(error);
            }
        }
        try {
            const APIClient = await this.getAPIClient();
            const note = await APIClient.createNote(options);
            core_1.ux.table([note], {
                id: {
                    header: 'ID',
                },
                title: {},
                userPath: {
                    header: 'User path',
                },
                teamPath: {
                    header: 'Team path',
                },
            }, Object.assign({ printLine: this.log.bind(this) }, flags));
        }
        catch (error) {
            this.log('Create note failed');
            this.error(error);
        }
    }
}
CreateCommand.description = 'Create a note';
CreateCommand.examples = [
    "notes create --content='# A new note' --readPermission=owner --writePermission=owner --commentPermission=disabled",
    `ID                     Title                            User Path               Team Path
────────────────────── ──────────────────────────────── ──────────────────────  ────────
raUuSTetT5uQbqQfLnz9lA A new note                       gvfz2UB5THiKABQJQnLs6Q  null`,
    'Or you can pipe content via Unix pipeline:',
    'cat README.md | hackmd-cli notes create',
];
CreateCommand.flags = Object.assign({ help: core_1.Flags.help({ char: 'h' }), title: flags_1.noteTitle, content: flags_1.noteContent, readPermission: flags_1.notePermission, writePermission: flags_1.notePermission, commentPermission: flags_1.commentPermission,
    editor: flags_1.editor }, core_1.ux.table.flags());
exports.default = CreateCommand;
