"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const core_1 = require("@oclif/core");
const command_1 = tslib_1.__importDefault(require("../../command"));
const flags_1 = require("../../flags");
class IndexCommand extends command_1.default {
    async run() {
        const { flags } = await this.parse(IndexCommand);
        try {
            const APIClient = await this.getAPIClient();
            const notes = flags.noteId ? [await APIClient.getNote(flags.noteId)] : await APIClient.getNoteList();
            core_1.ux.table(notes, {
                id: {
                    header: 'ID',
                },
                title: {},
                userPath: {
                    header: 'User Path',
                },
                teamPath: {
                    header: 'Team Path',
                },
            }, Object.assign({ printLine: this.log.bind(this) }, flags));
        }
        catch (error) {
            this.log('Fetch user notes failed');
            this.error(error);
        }
    }
}
IndexCommand.description = 'HackMD notes commands';
IndexCommand.examples = [
    `$ hackmd-cli notes
ID                     Title                            User Path               Team Path
────────────────────── ──────────────────────────────── ────────────────────── ────────
raUuSTetT5uQbqQfLnz9lA CLI test note                    gvfz2UB5THiKABQJQnLs6Q null     `,
];
IndexCommand.flags = Object.assign({ help: core_1.Flags.help({ char: 'h' }), noteId: flags_1.noteId }, core_1.ux.table.flags());
exports.default = IndexCommand;
