"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const core_1 = require("@oclif/core");
const command_1 = tslib_1.__importDefault(require("../../command"));
const flags_1 = require("../../flags");
class Update extends command_1.default {
    async run() {
        const { flags } = await this.parse(Update);
        const { noteId, content } = flags;
        if (!noteId) {
            this.error('Flag noteId could not be empty');
        }
        try {
            const APIClient = await this.getAPIClient();
            await APIClient.updateNoteContent(noteId, content);
        }
        catch (error) {
            this.log('Update note content failed');
            this.error(error);
        }
    }
}
Update.description = 'Update note content';
Update.examples = [
    "$ hackmd-cli notes update --noteId=WNkLM6gkS0Cg2cQ8rv7bYA --content='# A new title'",
];
Update.flags = {
    help: core_1.Flags.help({ char: 'h' }),
    noteId: flags_1.noteId,
    content: flags_1.noteContent,
};
exports.default = Update;
