"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const core_1 = require("@oclif/core");
const command_1 = tslib_1.__importDefault(require("../../command"));
const flags_1 = require("../../flags");
class Delete extends command_1.default {
    async run() {
        const { flags } = await this.parse(Delete);
        const { teamPath, noteId } = flags;
        if (!teamPath) {
            this.error('Flag teamPath could not be empty');
        }
        if (!noteId) {
            this.error('Flag noteId could not be empty');
        }
        try {
            const APIClient = await this.getAPIClient();
            await APIClient.deleteTeamNote(teamPath, noteId);
        }
        catch (error) {
            this.log('Delete team note failed');
            this.error(error);
        }
    }
}
Delete.description = 'Delete a team note';
Delete.examples = [
    '$ hackmd-cli team-notes delete --teamPath=CLI-test --noteId=WNkLM6gkS0Cg2cQ8rv7bYA',
];
Delete.flags = {
    help: core_1.Flags.help({ char: 'h' }),
    teamPath: flags_1.teamPath,
    noteId: flags_1.noteId,
};
exports.default = Delete;
