"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const core_1 = require("@oclif/core");
const command_1 = tslib_1.__importDefault(require("../../command"));
const flags_1 = require("../../flags");
class IndexCommand extends command_1.default {
    async run() {
        const { flags } = await this.parse(IndexCommand);
        if (!flags.teamPath) {
            this.error('Flag teamPath could not be empty');
        }
        try {
            const APIClient = await this.getAPIClient();
            const notes = await APIClient.getTeamNotes(flags.teamPath);
            core_1.ux.table(notes, {
                id: {
                    header: 'ID',
                },
                title: {},
                userPath: {
                    header: 'User path',
                },
                teamPath: {
                    header: 'Team path',
                },
            }, Object.assign({ printLine: this.log.bind(this) }, flags));
        }
        catch (error) {
            this.log('Fetch team notes failed');
            this.error(error);
        }
    }
}
IndexCommand.description = 'HackMD team-notes commands';
IndexCommand.examples = [
    `$ hackmd-cli team-notes --teamPath=CLI-test
ID                     Title                            User path Team path
────────────────────── ──────────────────────────────── ──────── ────────
WNkLM6gkS0Cg2cQ8rv7bYA a team note                      null     CLI-test
BnC6gN0_TfStV2KKmPPXeg Welcome to your team's workspace null     CLI-test`,
];
IndexCommand.flags = Object.assign({ help: core_1.Flags.help({ char: 'h' }), teamPath: flags_1.teamPath }, core_1.ux.table.flags());
exports.default = IndexCommand;
