"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const core_1 = require("@oclif/core");
const command_1 = tslib_1.__importDefault(require("../../command"));
const flags_1 = require("../../flags");
class Update extends command_1.default {
    async run() {
        const { flags } = await this.parse(Update);
        const { teamPath, noteId, content } = flags;
        if (!teamPath) {
            this.error('Flag teamPath could not be empty');
        }
        if (!noteId) {
            this.error('Flag noteId could not be empty');
        }
        try {
            const APIClient = await this.getAPIClient();
            await APIClient.updateTeamNoteContent(teamPath, noteId, content);
        }
        catch (error) {
            this.log('Update team note content failed');
            this.error(error);
        }
    }
}
Update.description = 'Update team note content';
Update.examples = [
    "$ hackmd-cli team-notes update --teamPath=CLI-test --noteId=WNkLM6gkS0Cg2cQ8rv7bYA --content='# A new title'",
];
Update.flags = {
    help: core_1.Flags.help({ char: 'h' }),
    teamPath: flags_1.teamPath,
    noteId: flags_1.noteId,
    content: flags_1.noteContent,
};
exports.default = Update;
