"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const core_1 = require("@oclif/core");
const command_1 = tslib_1.__importDefault(require("../command"));
class Teams extends command_1.default {
    async run() {
        const { flags } = await this.parse(Teams);
        try {
            const APIClient = await this.getAPIClient();
            const notes = await APIClient.getTeams();
            core_1.ux.table(notes, {
                id: {
                    header: 'ID',
                },
                name: {},
                path: {},
                ownerId: {
                    header: 'Owner ID',
                },
            }, Object.assign({ printLine: this.log.bind(this) }, flags));
        }
        catch (error) {
            this.log('Fetch teams failed');
            this.error(error);
        }
    }
}
Teams.description = 'List teams';
Teams.examples = [
    `$ hackmd-cli teams
ID                                   Name          Path     Owner ID
──────────────────────────────────── ───────────── ──────── ────────────────────────────────────
f76308a6-d77a-41f6-86d0-8ada426a6fb4 CLI test team CLI-test 82f7f3d9-4079-4c78-8a00-14094272ece9 `,
];
Teams.flags = Object.assign({ help: core_1.Flags.help({ char: 'h' }) }, core_1.ux.table.flags());
exports.default = Teams;
