"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const core_1 = require("@oclif/core");
const command_1 = tslib_1.__importDefault(require("../command"));
class Whoami extends command_1.default {
    async run() {
        const { flags } = await this.parse(Whoami);
        try {
            const APIClient = await this.getAPIClient();
            const user = await APIClient.getMe();
            core_1.ux.table([user], {
                id: {
                    header: 'ID',
                },
                name: {},
                email: {},
                userPath: {
                    header: 'User Path',
                },
            }, Object.assign({ printLine: this.log.bind(this) }, flags));
        }
        catch (error) {
            this.log('Fetch user info failed');
            this.error(error);
        }
    }
}
Whoami.description = 'Show current user information';
Whoami.examples = [
    `$ hackmd-cli whoami
ID                                   Name           Email User path
──────────────────────────────────── ────────────── ───── ──────────────────────
82f7f3d9-4079-4c78-8a00-14094272ece9 Ming-Hsiu Tsai null  gvfz2UB5THiKABQJQnLs6Q  `,
];
Whoami.flags = Object.assign({ help: core_1.Flags.help({ char: 'h' }) }, core_1.ux.table.flags());
exports.default = Whoami;
