"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const fs = tslib_1.__importStar(require("fs-extra"));
const lodash_defaults_1 = tslib_1.__importDefault(require("lodash.defaults"));
const utils_1 = require("./utils");
const configFilePath = (0, utils_1.getConfigFilePath)();
const defaultConfig = {
    hackmdAPIEndpointURL: 'https://api.hackmd.io/v1',
};
const envConfig = {
    hackmdAPIEndpointURL: process.env.HMD_API_ENDPOINT_URL,
    accessToken: process.env.HMD_API_ACCESS_TOKEN,
};
// look for a readable config file; we can merge it with the env.
let hasExistingConfigFile = false;
try {
    fs.accessSync(configFilePath, fs.constants.R_OK);
    hasExistingConfigFile = true;
    // tslint:disable-next-line: no-unused
}
catch (_a) {
    // noop
}
let readConfig = {};
if (hasExistingConfigFile) {
    try {
        readConfig = JSON.parse(fs.readFileSync(configFilePath, 'utf-8'));
    }
    catch (error) {
        throw new Error(`

Could not read JSON config file at ${configFilePath}. Encountered exception:

${error}

`);
    }
}
// prefer environment config over file config
const config = (0, lodash_defaults_1.default)(envConfig, readConfig, defaultConfig);
exports.default = config;
