"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.temporaryMD = exports.safeStdinRead = exports.setAccessTokenConfig = exports.getConfigFilePath = void 0;
const tslib_1 = require("tslib");
const fs_extra_1 = tslib_1.__importDefault(require("fs-extra"));
const node_os_1 = require("node:os");
const path = tslib_1.__importStar(require("node:path"));
function getConfigFilePath() {
    const configDir = process.env.HMD_CLI_CONFIG_DIR ? process.env.HMD_CLI_CONFIG_DIR || '' : path.join((0, node_os_1.homedir)(), '.hackmd');
    const configPath = path.join(configDir, 'config.json');
    if (!fs_extra_1.default.existsSync(configDir)) {
        fs_extra_1.default.ensureFileSync(configPath);
        fs_extra_1.default.writeFileSync(configPath, JSON.stringify({}));
    }
    return configPath;
}
exports.getConfigFilePath = getConfigFilePath;
function setAccessTokenConfig(token) {
    const configFilePath = getConfigFilePath();
    const newConfigFile = require(configFilePath);
    newConfigFile.accessToken = token;
    fs_extra_1.default.writeFile(configFilePath, JSON.stringify(newConfigFile, null, 2), function (err) {
        if (err) {
            throw err;
        }
    });
}
exports.setAccessTokenConfig = setAccessTokenConfig;
function safeStdinRead() {
    let result;
    try {
        result = fs_extra_1.default.readFileSync(process.stdin.fd).toString();
    }
    catch (_a) { }
    return result;
}
exports.safeStdinRead = safeStdinRead;
// generate temporary markdown file in /tmp directory
function temporaryMD() {
    const tmpDir = (0, node_os_1.tmpdir)();
    const filename = `temp_${Math.random().toString(36).slice(2)}.md`;
    const filePath = path.join(tmpDir, filename);
    return filePath;
}
exports.temporaryMD = temporaryMD;
